@@ -39,7 +39,7 @@ def cm_precipitation_metpy():
     return mpl.colors.ListedColormap(colors, 'precipitation')
 
 
-def cm_precipitation_nws(atime=24):
+def cm_precipitation_nws(atime=24, return_norm=False):
     """
     http://jjhelmus.github.io/blog/2013/09/17/plotting-nsw-precipitation-data/
 
@@ -55,12 +55,16 @@ def cm_precipitation_nws(atime=24):
         clevs = [0.01, 1, 3, 5, 10, 15, 20, 25, 30, 40, 50, 60, 80, 100, 120]
     else:
         clevs = [0.1, 2.5, 5, 10, 15, 20, 25, 30, 40, 50, 75, 100, 150, 200, 250]
+        
     colors = ["#04e9e7", "#019ff4", "#0300f4", "#02fd02",
               "#01c501", "#008e00", "#fdf802", "#e5bc00",
               "#fd9500", "#fd0000", "#d40000", "#bc0000",
               "#f800fd", "#dd1c77", "#9854c6"]
-    cmap, norm = mpl.colors.from_levels_and_colors(clevs, colors, extend='max')
-    return cmap, norm
+    if return_norm:
+        cmap, norm = mpl.colors.from_levels_and_colors(clevs, colors, extend='max')
+        return cmap, norm
+    else:
+        return make_cmap(colors, position=clevs, in_hex=True)
 
 
 def cm_rain_nws(atime=24, pos=None):
@@ -499,7 +503,7 @@ def cm_temperature_nws(pos=None):
             -45, -30, -20, -10, -5, 0, 0, 5, 5, 10, 20, 20, 30, 30, 40, 45])
     else:
         _pos = pos
-    return make_cmap(_colors, position=_pos, rgb=True)
+    return make_cmap(_colors, position=_pos, in_rgb=True)
 
 
 def cm_temp():
@@ -589,7 +593,7 @@ def cm_sftemp():
 
      
     sfc_coltbl = mpl.colors.LinearSegmentedColormap('SFC_COLTBL',sfc_cdict)
-    return sfc_coltbl 
+    return sfc_coltbl
 
 
 def cm_temperature_trend_nws(pos=None):
@@ -743,14 +747,14 @@ def cm_wind_speed_nws(pos=None):
     _colors = [
         [255, 255, 255], [99, 99, 99], [28, 99, 207], [177, 238, 239],
         [60, 206, 77], [197, 254, 189], [251, 249, 173], [163, 14, 19],
-        [95, 61, 54], [221, 186, 177], [241, 218, 209], [209, 83, 80]
-    ]
+        [95, 61, 54], [221, 186, 177], [241, 218, 209], [209, 83, 80]]
     if pos is None:
         _pos = np.array(
             [0, 3.6, 3.6, 10.8, 10.8, 17.2, 17.2, 24.5, 24.5, 32.7, 32.7, 42])
     else:
         _pos = pos
-    return make_cmap(_colors, position=_pos, rgb=True)
+        
+    return make_cmap(_colors, position=_pos, in_rgb=True)
 
 
 def cm_wind():
@@ -931,7 +935,7 @@ def cm_dpt():
     return cmap
 
 
-def cm_relative_humidity_nws(pos=None):
+def cm_relative_humidity_nws(pos=None, return_norm=False):
     """
     Construct 10m relative humidity color maps.
     
@@ -951,9 +955,12 @@ def cm_relative_humidity_nws(pos=None):
         _pos = pos
 
     # construct color map and normalized boundary
-    cmap, norm = mpl.colors.from_levels_and_colors(
-        _pos, _colors, extend='max')
-    return cmap, norm
+    if return_norm:
+        cmap, norm = mpl.colors.from_levels_and_colors(
+            _pos, _colors, extend='max')
+        return cmap, norm
+    else:
+        return make_cmap(_colors, position=_pos, in_rgb=True)
 
 
 def cm_rh():
@@ -985,7 +992,7 @@ def cm_rh():
     # Create the colormap
     cmap = mpl.colors.LinearSegmentedColormap.from_list("rh", COLORS)
 
-    return cmap
+    return cmap, norm
 
 
 def cm_cloud_cover_nws(pos=None):
@@ -1002,7 +1009,7 @@ def cm_cloud_cover_nws(pos=None):
     else:
         _pos = pos
 
-    return make_cmap(_colors, position=_pos, hex=True)
+    return make_cmap(_colors, position=_pos, in_hex=True)
 
 
 def cm_sky():
@@ -1194,7 +1201,7 @@ def cm_specific_humidity_nws(pos=None):
     else:
         _pos = [0, 4, 8, 8, 12, 12, 16, 16, 20, 20, 24]
 
-    return make_cmap(_colors, position=_pos, hex=True)
+    return make_cmap(_colors, position=_pos, in_hex=True)
 
 
 def cm_high_temperature_nws(pos=None):
@@ -1216,7 +1223,7 @@ def cm_high_temperature_nws(pos=None):
         _pos = [-60, -50, -40, -35, -30, -25, -20, -15, -10, -5, 0,
                 0, 5, 10, 15, 20, 25, 30, 35, 40]
 
-    return make_cmap(_colors, position=_pos, hex=True)
+    return make_cmap(_colors, position=_pos, in_hex=True)
 
 
 def cm_high_thermal_temperature_nws(pos=None):
@@ -1264,7 +1271,7 @@ def cm_cape_nws(pos=None):
             0, 100, 150, 500, 900, 1300, 1500, 1800,
             2000, 2850, 3600, 3900, 4200, 4950])
     
-    return make_cmap(_colors, position=_pos, hex=True)
+    return make_cmap(_colors, position=_pos, in_hex=True)
 
 
 def cm_terrain_256():
